Method: LanguageServer::Protocol::Interfaces::SignatureHelp#active_parameter
- Defined in:
- lib/language_server/protocol/interfaces/signature_help.rb
#active_parameter ⇒ number
The active parameter of the active signature. If omitted or the value
lies outside the range of signatures[activeSignature].parameters
defaults to 0 if the active signature has parameters. If
the active signature has no parameters it is ignored.
In future version of the protocol this property might become
mandantory to better express the active parameter if the
active signature does have any.
52 53 54 |
# File 'lib/language_server/protocol/interfaces/signature_help.rb', line 52 def active_parameter attributes.fetch(:activeParameter) end |